pub fn parse_initialize_event_hypersync( dex: SharedDex, log: &HypersyncLog, ) -> Result<InitializeEvent>
Parses an initialize event from a Uniswap V3 log.
Returns an error if the log parsing fails or if the event data is invalid.
Panics if the contract address is not set in the log.